back_trans <- function(gtt,outm=NULL,sqrts=NULL,logs=NULL,log1ps=NULL){
## Handles back-transformation for non-strat and strat
## 
## gtt = gt table element
## outm = outcome meassure trans. One of c("log","log1p","sqrt"). The reciprocal function is used to back transform.
## sqrts = sqrt-trasformed variable names
## logs= log-trasformed variable names
## log1ps= log1p-trasformed variable names

  # gtt<-mul
  # outm<-"log1p"
  # sqrts <- "pase_0"
  # logs <- "nihss_0"
  
  ests<-colnames(dplyr::select(gtt$table_body,contains("estimate")))
  lows<-colnames(dplyr::select(gtt$table_body,contains("conf.low")))
  highs<-colnames(dplyr::select(gtt$table_body,contains("conf.high")))
  
  sqrt_ci <- function(gtt,all.v=FALSE,var=NULL){
  # Sqrt-transformation function to account for negative coefficients.
    if (all.v){
      var<-gtt$table_body$variable
    }
    
    # There is a
    
    for (i in var){
      for (j in ests){
        est<-gtt$table_body[gtt$table_body$variable==i,][j]
        
        if (0 > est){
          gtt$table_body[gtt$table_body$variable==i,][j]<- (0-(est^2))
        } else {
          gtt$table_body[gtt$table_body$variable==i,][j]<- (est^2) 
        }
      }
      
      for (j in lows){
        low<-gtt$table_body[gtt$table_body$variable==i,][j]
        
        if (0 > low){
          gtt$table_body[gtt$table_body$variable==i,][j]<- (0-(low^2))
        } else {
          gtt$table_body[gtt$table_body$variable==i,][j]<- (low^2) 
        }
      }
      
      for (j in highs){
        high<-gtt$table_body[gtt$table_body$variable==i,][j]
        
        if (0 > high){
          gtt$table_body[gtt$table_body$variable==i,][j]<- (0-(high^2))
        } else {
          gtt$table_body[gtt$table_body$variable==i,][j]<- (high^2) 
        }
      }
    }
    return(gtt)
  }
  
  log_ci <- function(gtt,all.v=FALSE,var=NULL){
    # Log-transformation function
    if (all.v){
      var<-gtt$table_body$variable
    }
    
    for (i in var){
      for (j in ests){
        gtt$table_body[gtt$table_body$variable==i,][j]<-
          exp(gtt$table_body[gtt$table_body$variable==i,][j])
      }
      
      for (j in lows){
        gtt$table_body[gtt$table_body$variable==i,][j]<-
          exp(gtt$table_body[gtt$table_body$variable==i,][j])
        
      }
      
      for (j in highs){
        gtt$table_body[gtt$table_body$variable==i,][j]<-
          exp(gtt$table_body[gtt$table_body$variable==i,][j])
      }
    }
    return(gtt)
  }
  
  log1p_ci <- function(gtt,all.v=FALSE,var=NULL){
    # Log1p-transformation function
    if (all.v){
      var<-gtt$table_body$variable
    }
    
    for (i in var){
      for (j in ests){
        gtt$table_body[gtt$table_body$variable==i,][j]<-
          expm1(gtt$table_body[gtt$table_body$variable==i,][j])
      }
      
      for (j in lows){
        gtt$table_body[gtt$table_body$variable==i,][j]<-
          expm1(gtt$table_body[gtt$table_body$variable==i,][j])
        
      }
      
      for (j in highs){
        gtt$table_body[gtt$table_body$variable==i,][j]<-
          expm1(gtt$table_body[gtt$table_body$variable==i,][j])
      }
    }
    return(gtt)
  }
  
  if (outm=="log1p"){
    ## Transforming log1p() to expm1()
    gtt<-log1p_ci(gtt,all.v=TRUE)
  }
  
  if (outm=="log"){
    ## Transforming log1p() to expm1()
    gtt<-log_ci(gtt,all.v=TRUE)
  }
  
  if (outm=="sqrt"){
    gtt<-sqrt_ci(gtt,all.v=TRUE)
  }
  
  # Sqrts
  gtt<-sqrt_ci(gtt,var=sqrts)

  # Log1ps
  gtt<-log1p_ci(gtt, var=log1ps)
  
  # Logs
  gtt<-log_ci(gtt, var=logs)
  

return(gtt)
}
